@@ -38,7 +38,7 @@ class Editor (hildon.TextView):
   def __init__ (self,language=None,font_name='Monospace',font_size='11'):
 
 #    self.language_manager=gtksourceview2.LanguageManager()
-    if language != None:
+    if (language != None) and (language != 'None'):
       lang = SyntaxLoader(language)
     else:
       lang = None
@@ -121,6 +121,8 @@ class Editor (hildon.TextView):
     return False
 
   def reset_language(self,language):
+    if (language == 'None'):
+      language=None
     self.language = language
     lang = SyntaxLoader(self.language)
     self.buffer.reset_language(lang)
