@@ -125,6 +125,13 @@ Roadmap :
 ◦ Recent Chooser Change
 ◦ Prefs show lines numbers
 
+• Version 3.0.5 :
+◦ Fix 2 syntax errors
+
+• Version 3.0.6 :
+◦ Fix None default language : #8074
+◦ Detect .txt as text file (no syntax hilight)
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
